@@ -190,28 +190,19 @@ unsigned _libmsi_query_open( LibmsiDatabase *db, LibmsiQuery **view, const char
 {
     GError *err = NULL;
     unsigned r = LIBMSI_RESULT_SUCCESS;
-    int size = 100, res;
     char *query;
+    va_list va;
+
+    va_start(va, fmt);
+    query = g_strdup_vprintf(fmt, va);
+    va_end(va);
 
-    /* construct the string */
-    for (;;)
-    {
-        va_list va;
-        query = msi_alloc( size*sizeof(char) );
-        va_start(va, fmt);
-        res = vsnprintf(query, size, fmt, va);
-        va_end(va);
-        if (res == -1) size *= 2;
-        else if (res >= size) size = res + 1;
-        else break;
-        msi_free( query );
-    }
-    /* perform the query */
     *view = libmsi_query_new (db, query, &err);
     if (err)
         r = err->code;
     g_clear_error (&err);
-    msi_free(query);
+
+    g_free(query);
     return r;
 }
 
@@ -262,30 +253,20 @@ LibmsiRecord *_libmsi_query_get_record( LibmsiDatabase *db, const char *fmt, ...
 {
     LibmsiRecord *rec = NULL;
     LibmsiQuery *view = NULL;
-    unsigned r;
-    int size = 100, res;
+    unsigned r = LIBMSI_RESULT_SUCCESS;
+    va_list va;
     char *query;
     GError *error = NULL; // FIXME: move error to caller
 
-    /* construct the string */
-    for (;;)
-    {
-        va_list va;
-        query = msi_alloc( size*sizeof(char) );
-        va_start(va, fmt);
-        res = vsnprintf(query, size, fmt, va);
-        va_end(va);
-        if (res == -1) size *= 2;
-        else if (res >= size) size = res + 1;
-        else break;
-        msi_free( query );
-    }
-    /* perform the query */
+    va_start(va, fmt);
+    query = g_strdup_vprintf(fmt, va);
+    va_end(va);
+
     view = libmsi_query_new (db, query, &error);
     if (error)
         r = error->code;
     g_clear_error (&error);
-    msi_free(query);
+    g_free(query);
 
     if( r == LIBMSI_RESULT_SUCCESS )
     {
@@ -326,7 +307,7 @@ unsigned msi_view_get_row(LibmsiDatabase *db, LibmsiView *view, unsigned row, Li
         ret = view->ops->get_column_info(view, i, NULL, &type, NULL, NULL);
         if (ret)
         {
-            ERR("Error getting column type for %d\n", i);
+            g_critical("Error getting column type for %d\n", i);
             continue;
         }
 
@@ -341,7 +322,7 @@ unsigned msi_view_get_row(LibmsiDatabase *db, LibmsiView *view, unsigned row, Li
                 g_object_unref(G_OBJECT(stm));
             }
             else
-                WARN("failed to get stream\n");
+                g_warning("failed to get stream\n");
 
             continue;
         }
@@ -349,12 +330,12 @@ unsigned msi_view_get_row(LibmsiDatabase *db, LibmsiView *view, unsigned row, Li
         ret = view->ops->fetch_int(view, row, i, &ival);
         if (ret)
         {
-            ERR("Error fetching data for %d\n", i);
+            g_critical("Error fetching data for %d\n", i);
             continue;
         }
 
         if (! (type & MSITYPE_VALID))
-            ERR("Invalid type!\n");
+            g_critical("Invalid type!\n");
 
         /* check if it's nul (0) - if so, don't set anything */
         if (!ival)
